<?php
if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

class WooCommercePageBuilder_Admin{
	
	/**
	 * Constructor.
	 *
	 * @since 1.0
	 */
	public function __construct(){

		add_action ('admin_init', array($this,'init'));
		add_action ('admin_enqueue_scripts',array($this,'enqueue_styles'));
		add_action ('admin_enqueue_scripts',array($this,'enqueue_scripts'));
		add_action ('admin_menu', array($this,'admin_menu') );
		add_filter( 'admin_footer_text', array( $this, 'admin_footer_text' ), 1 );
		
		// Product, checkout page meta data
		add_action('add_meta_boxes', array($this, 'add_meta_boxes'));
		add_action('save_post', array($this, 'save_product_meta_data'), 10, 2 );
		
		// Product category add fields
		add_action('product_cat_add_form_fields', array($this, 'add_category_fields'));
		add_action('product_cat_edit_form_fields', array($this, 'edit_category_fields'), 10, 2);

		// Product Tag add fields
		add_action('product_tag_add_form_fields', array($this, 'add_product_tag_fields'));
		add_action('product_tag_edit_form_fields', array($this, 'edit_product_tag_fields'), 10, 2);

		// Save custom fields
		add_action('created_term', array($this, 'save_category_fields'), 10, 3);
		add_action('edit_term', array($this, 'save_category_fields'), 10, 3);
		
	}
	
	public function init(){
		register_setting('dtwpb_settings', 'dtwpb_settings');
	}
	
	public function enqueue_styles(){
		wp_enqueue_style('dtwpb-admin', DT_WOOCOMMERCE_PAGE_BUILDER_PLUGIN_URL . 'assets/css/admin.css');
		wp_enqueue_style('font-awesome', DT_WOOCOMMERCE_PAGE_BUILDER_PLUGIN_URL . 'assets/css/fonts/font-awesome/css/font-awesome.min.css',  array(), '4.7.0' );
	}
	
	public function enqueue_scripts(){
		wp_enqueue_style( 'wp-color-picker' );
		wp_enqueue_script( 'wp-color-picker' );
		wp_register_script( 'dtwpb-admin',DT_WOOCOMMERCE_PAGE_BUILDER_PLUGIN_URL. 'assets/js/admin.js', array('jquery'),DT_WOOCOMMERCE_PAGE_BUILDER_VERSION,false );
		wp_enqueue_script( 'dtwpb-admin' );
		wp_enqueue_style( 'jquery-chosen', DT_WOOCOMMERCE_PAGE_BUILDER_PLUGIN_URL. 'assets/css/chosen/chosen.css' );
		wp_enqueue_script( 'jquery-chosen', DT_WOOCOMMERCE_PAGE_BUILDER_PLUGIN_URL . '/assets/js/chosen/chosen.jquery.js', array( 'jquery' ), '1.1.0', true );
	}
	
	/**
	 * Show row meta on the plugin screen.
	 *
	 * @param mixed $links Plugin Row Meta.
	 * @param mixed $file  Plugin Base file.
	 *
	 * @return array
	 */
	public static function plugin_row_meta( $links, $file ) {
	
		if ( DT_WOOCOMMERCE_PAGE_BUILDER_PLUGIN_BASENAME ===  $file ) {
			$row_meta = array(
				'documentation'    => '<a href="' . esc_url( apply_filters( 'dtwpb_docs_url', 'http://doc.dawnthemes.com/woocommerce-page-builder/' ) ) . '" target="_blank" aria-label="' . esc_attr__( 'View Documentation', 'dt_woocommerce_page_builder' ) . '">' . esc_html__( 'Documentation', 'dt_woocommerce_page_builder' ) . '</a>',
				'videos' => '<a href="' . esc_url( apply_filters( 'dtwpb_videos_url', 'https://www.youtube.com/watch?v=HIJ0-u67Aeo&list=PL_HbKbJsShUhl9s6GyBPRvZ6glDBpq6k4' ) ) . '" target="_blank" aria-label="' . esc_attr__( 'View Tutorial videos', 'dt_woocommerce_page_builder' ) . '">' . esc_html__( 'Tutorial videos', 'dt_woocommerce_page_builder' ) . '</a>',
				'support' => '<a href="' . esc_url( apply_filters( 'dtwpb_support_url', 'http://dawnthemes.com/support/forums/forum/plugins/woocommerce-page-builder/' ) ) . '" target="_blank" aria-label="' . esc_attr__( 'Visit premium customer support', 'dt_woocommerce_page_builder' ) . '">' . esc_html__( 'Support', 'dt_woocommerce_page_builder' ) . '</a>',
			);
			
			return array_merge( $links, $row_meta );
		}
	
		return (array) $links;
	}
	
	public function admin_menu() {
		define( 'DT_WOOCOMMERCE_PAGE_BUILDER_PAGE_MAIN_SLUG', 'woocommerce-page-builder-options' );
		define( 'DT_WOOCOMMERCE_PAGE_BUILDER_PAGE_SETTINGS_SLUG', 'woocommerce-page-builder-settings' );
		
		add_menu_page( esc_html__( 'WooCommerce Page Builder', 'dt_woocommerce_page_builder' ), esc_html__( 'WooCommerce Page Builder', 'dt_woocommerce_page_builder' ), 'edit_posts', DT_WOOCOMMERCE_PAGE_BUILDER_PAGE_MAIN_SLUG, null, 'dashicons-admin-page', '56');
		
		add_submenu_page( DT_WOOCOMMERCE_PAGE_BUILDER_PAGE_MAIN_SLUG, esc_html__( 'Welcome', 'dt_woocommerce_page_builder' ), esc_html__( 'Welcome', 'dt_woocommerce_page_builder' ), 'manage_options', DT_WOOCOMMERCE_PAGE_BUILDER_PAGE_MAIN_SLUG, array( $this, 'welcome' ) );
		add_submenu_page( DT_WOOCOMMERCE_PAGE_BUILDER_PAGE_MAIN_SLUG, esc_html__( 'Registration', 'dt_woocommerce_page_builder' ), esc_html__( 'Registration', 'dt_woocommerce_page_builder' ), 'manage_options', 'woocommerce-page-builder-registration', array( $this, 'registration' ) );
		add_submenu_page( DT_WOOCOMMERCE_PAGE_BUILDER_PAGE_MAIN_SLUG, esc_html__( 'Demos', 'dt_woocommerce_page_builder' ), esc_html__( 'Demos', 'dt_woocommerce_page_builder' ), 'manage_options', 'woocommerce-page-builder-demos', array( $this, 'demos' ) );
		add_submenu_page( DT_WOOCOMMERCE_PAGE_BUILDER_PAGE_MAIN_SLUG, esc_html__( 'Settings', 'woocommerce' ), esc_html__( 'Settings', 'woocommerce' ), 'manage_options', 'woocommerce-page-builder-settings', array( $this, 'settings' ) );
		
		$labels = dtwpb_posttype_product_tpl::getPostTypesLabels();
		add_submenu_page( DT_WOOCOMMERCE_PAGE_BUILDER_PAGE_MAIN_SLUG , $labels['name'], $labels['name'] , 'edit_posts' , 'edit.php?post_type=' . rawurlencode( dtwpb_posttype_product_tpl::postType() ), '' );
		
		$labels = dtwpb_posttype_archive_tpl::getPostTypesLabels();
		add_submenu_page( DT_WOOCOMMERCE_PAGE_BUILDER_PAGE_MAIN_SLUG , $labels['name'], $labels['name'] , 'edit_posts' , 'edit.php?post_type=' . rawurlencode( dtwpb_posttype_archive_tpl::postType() ), '' );
		
		$labels = DTWPB_Cart_Tpl::getPostTypesLabels();
		add_submenu_page( DT_WOOCOMMERCE_PAGE_BUILDER_PAGE_MAIN_SLUG , $labels['name'], $labels['name'] , 'edit_posts' , 'edit.php?post_type=' . rawurlencode( DTWPB_Cart_Tpl::postType() ), '' );
		
		$labels = DTWPB_Checkout_Tpl::getPostTypesLabels();
		add_submenu_page( DT_WOOCOMMERCE_PAGE_BUILDER_PAGE_MAIN_SLUG , $labels['name'], $labels['name'] , 'edit_posts' , 'edit.php?post_type=' . rawurlencode( DTWPB_Checkout_Tpl::postType() ), '' );
		
		$labels = DTWPB_Thankyou_Tpl::getPostTypesLabels();
		add_submenu_page( DT_WOOCOMMERCE_PAGE_BUILDER_PAGE_MAIN_SLUG , $labels['name'], $labels['name'] , 'edit_posts' , 'edit.php?post_type=' . rawurlencode( DTWPB_Thankyou_Tpl::postType() ), '' );
		
		$labels = DTWPB_MyAccount_Tpl::getPostTypesLabels();
		add_submenu_page( DT_WOOCOMMERCE_PAGE_BUILDER_PAGE_MAIN_SLUG , $labels['name'], $labels['name'] , 'edit_posts' , 'edit.php?post_type=' . rawurlencode( DTWPB_MyAccount_Tpl::postType() ), '' );
		
		do_action( 'dtwpb_menu_page_build' );
	}
	
	public function welcome(){
		require_once DT_WOOCOMMERCE_PAGE_BUILDER_PLUGIN_DIR . 'includes/admin/admin-screens/welcome.php';
	}
	
	public function registration(){
		require_once DT_WOOCOMMERCE_PAGE_BUILDER_PLUGIN_DIR . 'includes/admin/admin-screens/registration.php';
	}
	
	public function demos(){
		require_once DT_WOOCOMMERCE_PAGE_BUILDER_PLUGIN_DIR . 'includes/admin/admin-screens/demos.php';
	}
	
	public function settings(){
		require_once DT_WOOCOMMERCE_PAGE_BUILDER_PLUGIN_DIR . 'includes/admin/admin-screens/settings.php';
	}
	
	/**
	 * Adds the header.
	 *
	 * @static
	 * @access public
	 */
	public static function header() {
		?>
		<h1><?php echo esc_html( apply_filters( 'woocommerce_page_builder_admin_welcome_title', esc_html__( 'Welcome to WooCommerce Page Builder!', 'dt_woocommerce_page_builder' ) ) ); ?></h1>
		<div class="about-text">
		<?php
		$welcome_text = sprintf( // phpcs:ignore WordPress.Security.EscapeOutput
			/* translators: Link attributes. */
			__( 'WooCommerce Page Builder is now installed and ready to use! Get ready to build something beautiful. Please <a %s>register your purchase</a> to receive automatic updates, import Demo and Settings. We hope you enjoy it!', 'dt_woocommerce_page_builder' ),
			'href="' . admin_url( 'admin.php?page=woocommerce-page-builder-registration' ) . '" target="_blank"'
		);
		echo apply_filters( 'woocommerce_page_builder_admin_welcome_text', $welcome_text ); // phpcs:ignore WordPress.Security.EscapeOutput ?>
		</div>
		<h2 class="nav-tab-wrapper">
			<?php
			self::admin_tab( esc_html__( 'Welcome', 'dt_woocommerce_page_builder' ), 'woocommerce-page-builder-options' );
			self::admin_tab( esc_html__( 'Registration', 'dt_woocommerce_page_builder' ), 'woocommerce-page-builder-registration' );
			self::admin_tab( esc_html__( 'Demos', 'dt_woocommerce_page_builder' ), 'woocommerce-page-builder-demos' );
			self::admin_tab( esc_html__( 'Settings', 'dt_woocommerce_page_builder' ), 'woocommerce-page-builder-settings' );
			?>
			<a href="http://doc.dawnthemes.com/woocommerce-page-builder/" class="nav-tab" target="_blank"><i class="fa fa-book" aria-hidden="true"></i></a>
			<a href="https://www.youtube.com/watch?v=HIJ0-u67Aeo&list=PL_HbKbJsShUhl9s6GyBPRvZ6glDBpq6k4" class="nav-tab" target="_blank"><i class="fa fa-play-circle" aria-hidden="true"></i></a>
			<a href="http://dawnthemes.com/support/" class="nav-tab" target="_blank"><i class="fa fa-life-ring" aria-hidden="true"></i></a>
		</h2>
		<?php
	}
	
	/**
	 * Add the title.
	 *
	 * @static
	 * @access protected
	 * @since 1.0
	 * @param string $title The title.
	 * @param string $page  The page slug.
	 */
	protected static function admin_tab( $title, $page ) {
	
		if ( isset( $_GET['page'] ) ) { // phpcs:ignore WordPress.Security.NonceVerification
			$active_page = sanitize_text_field( wp_unslash( $_GET['page'] ) ); // phpcs:ignore WordPress.Security.NonceVerification
		}
	
		if ( $active_page === $page ) {
			$link       = 'javascript:void(0);';
			$active_tab = ' nav-tab-active';
		} else {
			$link       = 'admin.php?page=' . $page;
			$active_tab = '';
		}
	
		// Exception for Templates page, Layouts tab is active.
		if ( 'page-layout-sections' === $active_page && 'page-layouts' === $page ) {
			$link       = 'javascript:void(0);';
			$active_tab = ' nav-tab-active';
		}
	
		echo '<a href="' . esc_url_raw( $link ) . '" class="nav-tab' . esc_attr( $active_tab ) . '">' . $title . '</a>'; // phpcs:ignore WordPress.Security.EscapeOutput
	
	}
	
	/**
	 * Adds the footer.
	 *
	 * @static
	 * @access public
	 */
	public static function footer() {
		
		$footer_text = sprintf(
			/* translators: 1: WooCommerce 2:: five stars */
			__( 'Thank you for choosing %1$s. We are honored and are fully dedicated to making your experience perfect. If you like %1$s please leave us a %2$s rating. A huge thanks in advance!', 'dt_woocommerce_page_builder' ),
			'<strong>WooCommerce Page Builder</strong>',
			'<a href="https://1.envato.market/9ZeAW" target="_blank" class="wc-rating-link" data-rated="' . esc_attr__( 'Thanks :)', 'dt_woocommerce_page_builder' ) . '">&#9733;&#9733;&#9733;&#9733;&#9733;</a>'
		);
		?>
			<div class="woocommerce-page-builder-thanks woocommerce-page-builder-thanks">
				<p class="description"><?php echo wp_kses( $footer_text , array( 'strong' => array(), 'a' => array( 'href' => array(), 'class' => array(), 'data-rated' => array(), 'title' => array(), )) ); ?></p>
			</div>
			<?php
	}
	
	public static function woocommerce_get_product_types(){
		$product_types = wc_get_product_types();
		$product_types['downloadable'] = esc_html__( 'Downloadable product', 'dt_woocommerce_page_builder' );
		$product_types['virtual'] = esc_html__( 'Virtual product', 'dt_woocommerce_page_builder' );
		return $product_types;
	}
	
	public static function settings_output(){
		?>
		<form method="post" action="options.php" id="woocommerce-page-builder-settings-form" name="woocommerce-page-builder-settings-form">
			<?php settings_fields('dtwpb_settings')?>
			<strong><?php esc_html_e('Product Page setup', 'dt_woocommerce_page_builder');?></strong><hr>
			<?php
			$dtwpb_product_tpl_type_page = dtwpb_get_option('dtwpb_product_tpl_type_page', 'dtwpb_product_tpl');
			$product_tpl =  ($dtwpb_product_tpl_type_page == 'page') ? 'page' : 'dtwpb_product_tpl';
			$products_tpl = get_posts(array('post_type'=> $product_tpl, 'post_status'=> 'publish,private', 'suppress_filters' => false, 'posts_per_page'=>-1));
			?>			
			<table class="form-table woocommerce-builder-product-settings">
				<tbody>
					<tr valign="top">
						<th scope="row"><label for="dtwpb_product_tpl_type_page"><?php esc_html_e('Template Type', 'dt_woocommerce_page_builder') ?></label></th>
						<td>
						<select name="dtwpb_settings[dtwpb_product_tpl_type_page]">
							<option value="dtwpb_product_tpl" <?php selected( $dtwpb_product_tpl_type_page, 'dtwpb_product_tpl', true )?> ><?php esc_html_e('Default', 'dt_woocommerce_page_builder'); ?></option>
							<option value="page" <?php selected( $dtwpb_product_tpl_type_page, 'page', true )?>><?php esc_html_e('Page', 'dt_woocommerce_page_builder'); ?></option>
						</select>
						<p class="description"><?php esc_html_e('Select the type of template you want to work on. (Hit SAVE CHANGES to apply)', 'dt_woocommerce_page_builder'); ?></p>
						</td>
					</tr>
					<tr valign="top">
						<th scope="row"><label for="dtwpb_single_product_page_df"><?php esc_html_e('Product Template Default', 'dt_woocommerce_page_builder') ?></label></th>
						<td>
						<?php 
						
						$dtwpb_single_product_page_df = dtwpb_get_option('dtwpb_single_product_page_df', '');
						echo '<select name="dtwpb_settings[dtwpb_single_product_page_df]" id="dtwpb_single_product_page_df" class="" data-placeholder="'.__( 'Select a product template&hellip;','dt_woocommerce_page_builder').'">';
						echo '<option value="">'. __( '-- None (Use theme layout) --','dt_woocommerce_page_builder') . '</option>';
						foreach ($products_tpl as $p_tpl) {
							echo '<option value="'. $p_tpl->ID .'" '. selected( $dtwpb_single_product_page_df, $p_tpl->ID, false ) .'>'. $p_tpl->post_title. '</option>';
						}
						echo '</select>';
						
						?>
						<p class="description">
							<?php esc_html_e('Select Product Template default for all Products.', 'dt_woocommerce_page_builder');
							if( !empty($dtwpb_single_product_page_df) ){
								echo '<a href="' . esc_url( esc_url( get_edit_post_link($dtwpb_single_product_page_df) ) ) . '"> '.esc_html__( 'Edit', 'dt_woocommerce_page_builder' ).'</a>';
							}
							?>
						</p>
						</td>					
					</tr>
				</tbody>
			</table>
			<div class="woocommerce-page-builder-registered">
			
				<?php if ( ! WooCommercePageBuilder_Manager()->registration->is_registered() ) : ?>
				<div class="woocommerce-page-builder-screenlock">
					<div>
					<?php /* translators: "Product Registration" link. */ ?>
					<?php printf( esc_html__( '%s to unlock Settings.', 'dt_woocommerce_page_builder' ), '<a href="' . esc_url_raw( admin_url( 'admin.php?page=woocommerce-page-builder-registration' ) ) . '">' . esc_attr__( 'Registration the plugin', 'dt_woocommerce_page_builder' ) . '</a>' ); ?>
					</div>
				</div>
				<?php endif; ?>
				<table class="form-table woocommerce-builder-product-types-settings">
					<tbody>
						<tr valign="top">
							<th scope="row"><label><?php esc_html_e('Product Type template:', 'dt_woocommerce_page_builder');?></label></th>
							<td></td>
						</tr>
						<?php 
						$product_types = self::woocommerce_get_product_types();
						
						foreach ((array) $product_types as $product_type => $product_type_label){
						?>
						<tr valign="top">
							<th scope="row"><label for="woocommerce_page_builder_product_simple_template"><?php echo esc_html($product_type_label); ?></label></th>
							<td>
							<?php
							$product_type_template = dtwpb_get_option('woocommerce_page_builder_product_template_'.$product_type, '');
							
							echo '<select name="dtwpb_settings[woocommerce_page_builder_product_template_'.$product_type.']" id="woocommerce_page_builder_product_simple_template'.$product_type.'" class="" data-placeholder="'.esc_html__( 'Select a product template&hellip;','dt_woocommerce_page_builder').'">';
							echo '<option value="">'. esc_html__( 'Select Product Type Template','dt_woocommerce_page_builder') . '</option>';
							foreach ($products_tpl as $p_tpl) {
								echo '<option value="'. $p_tpl->ID .'" '. selected( $product_type_template, $p_tpl->ID, false ) .'>'. $p_tpl->post_title. '</option>';
							}
							echo '</select>';
							
							?>
							<p class="description">
								<?php
								if( !empty($product_type_template) ){
									echo '<a href="' . esc_url( esc_url( get_edit_post_link($product_type_template) ) ) . '"> '.esc_html__( 'Edit', 'dt_woocommerce_page_builder' ).'</a>';
								}
								?>
							</p>
							</td>					
						</tr>
						<?php
						}
						?>
					</tbody>
				</table>
				<table class="form-table">
					<tbody>
						<?php $dtwpb_cat_tpl_type_page = dtwpb_get_option('dtwpb_cat_tpl_type_page', 'dtwpb_cat_tpl');?>
						<tr valign="top">
							<th scope="row"><label for="dtwpb_cat_tpl_type_page"><?php esc_html_e('Archive Template Type', 'dt_woocommerce_page_builder') ?></label></th>
							<td>
							<select name="dtwpb_settings[dtwpb_cat_tpl_type_page]">
								<option value="dtwpb_cat_tpl" <?php selected( $dtwpb_cat_tpl_type_page, 'dtwpb_cat_tpl', true )?> ><?php esc_html_e('Default', 'dt_woocommerce_page_builder'); ?></option>
								<option value="page" <?php selected( $dtwpb_cat_tpl_type_page, 'page', true )?>><?php esc_html_e('Page', 'dt_woocommerce_page_builder'); ?></option>
							</select>
							<p class="description"><?php esc_html_e('Select the type of template you want to work on. (Hit SAVE CHANGES to apply)', 'dt_woocommerce_page_builder'); ?></p>
							</td>
						</tr>
						
						<tr valign="top">
							<th scope="row"><label for="dtwpb_shop_custom_page_id"><?php esc_html_e('Shop Page', 'dt_woocommerce_page_builder') ?></label></th>
							<td>
							<?php 
							$shop_tpl = ($dtwpb_cat_tpl_type_page == 'page') ? 'page' : 'dtwpb_cat_tpl';
	
							$dtwpb_shop_custom_page_id = dtwpb_get_option('dtwpb_shop_custom_page_id', '');
							
							$product_archive_tpl = get_posts(array('post_type'=> $shop_tpl, 'post_status'=> 'publish,private', 'suppress_filters' => false, 'posts_per_page'=>-1));
							echo '<select name="dtwpb_settings[dtwpb_shop_custom_page_id]" id="dtwpb_shop_custom_page_id" class="" data-placeholder="'.__( 'Select Shop template&hellip;','dt_woocommerce_page_builder').'">';
							echo '<option value="">'. __( '-- None (Use theme layout) --','dt_woocommerce_page_builder') . '</option>';
							foreach ($product_archive_tpl as $s_tpl) {
								echo '<option value="'. $s_tpl->ID .'" '. selected( $dtwpb_shop_custom_page_id , $s_tpl->ID, false ) .'>'. $s_tpl->post_title. '</option>';
							}
							echo '</select>';
							?>
							<p class="description">
								<?php esc_html_e('Custom Shop Page', 'dt_woocommerce_page_builder');
									if( !empty($dtwpb_shop_custom_page_id) ){
										echo '<a href="'.esc_url( get_edit_post_link($dtwpb_shop_custom_page_id) ).'"> '.esc_html__('Edit', 'dt_woocommerce_page_builder').'</a>';
									}
								?>
							</p>
							</td>	
							</td>							
						</tr>
						
						<tr valign="top">
							<th scope="row"><label for="dtwpb_product_cat_custom_page_id"><?php esc_html_e('Categories Template Default', 'dt_woocommerce_page_builder') ?></label></th>
							<td>
							<?php 
							$product_cat_tpl = ($dtwpb_cat_tpl_type_page == 'page') ? 'page' : 'dtwpb_cat_tpl';
							
							$dtwpb_product_cat_custom_page_id = dtwpb_get_option('dtwpb_product_cat_custom_page_id', '');
							
							$cat_tpl = get_posts(array('post_type'=> $product_cat_tpl, 'post_status'=> 'publish,private', 'suppress_filters' => false, 'posts_per_page'=>-1));
							echo '<select name="dtwpb_settings[dtwpb_product_cat_custom_page_id]" id="dtwpb_product_cat_custom_page_id" class="" data-placeholder="'.__( 'Select a category template&hellip;','dt_woocommerce_page_builder').'">';
							echo '<option value="">'. __( '-- None (Use theme layout) --','dt_woocommerce_page_builder') . '</option>';
							foreach ($cat_tpl as $c_tpl) {
								echo '<option value="'. $c_tpl->ID .'" '. selected( $dtwpb_product_cat_custom_page_id , $c_tpl->ID, false ) .'>'. $c_tpl->post_title. '</option>';
							}
							echo '</select>';
							
							?>
							<p class="description">
							<?php 
								echo __('Select Product Archive Template default for Category Page <br/>Or you can go to the specific category and setting <strong>DTWPB Product Archive Page</strong> option for each category. (One Custom Product Archive for one Product category)', 'dt_woocommerce_page_builder');
								echo '<br/>';
								if( !empty($dtwpb_product_cat_custom_page_id) ){
									echo '<a href="'.esc_url( get_edit_post_link($dtwpb_product_cat_custom_page_id) ).'"> '.esc_html__('Edit', 'dt_woocommerce_page_builder').'</a>';
								}
							?>
							</p>
							</td>							
						</tr>
						
						<tr valign="top">
							<th scope="row"><label for="dtwpb_product_tag_custom_page_id"><?php esc_html_e('Tags Template Default', 'dt_woocommerce_page_builder') ?></label></th>
							<td>
							<?php 
							$product_tag_tpl = ($dtwpb_cat_tpl_type_page == 'page') ? 'page' : 'dtwpb_cat_tpl';
							
							$dtwpb_product_tag_custom_page_id = dtwpb_get_option('dtwpb_product_tag_custom_page_id', '');
							
							$tag_tpl = get_posts(array('post_type'=> $product_tag_tpl, 'post_status'=> 'publish,private', 'suppress_filters' => false, 'posts_per_page'=>-1));
							echo '<select name="dtwpb_settings[dtwpb_product_tag_custom_page_id]" id="dtwpb_product_tag_custom_page_id" class="" data-placeholder="'.__( 'Select a category template&hellip;','dt_woocommerce_page_builder').'">';
							echo '<option value="">'. __( '-- None (Use theme layout) --','dt_woocommerce_page_builder') . '</option>';
							foreach ($tag_tpl as $t_tpl) {
								echo '<option value="'. $t_tpl->ID .'" '. selected( $dtwpb_product_tag_custom_page_id , $t_tpl->ID, false ) .'>'. $t_tpl->post_title. '</option>';
							}
							echo '</select>';
							
							?>
							<p class="description">
							<?php 
								echo __('Select Product Archive Template default for Product Tag page<br/>Or you can go to the specific tag and setting <strong>DTWPB Product Archive Page</strong> option for each Tag. (One Custom Product Archive for one Product Tag)', 'dt_woocommerce_page_builder');
								echo '<br/>';
								if( !empty($dtwpb_product_tag_custom_page_id) ){
									echo '<a href="'.esc_url( get_edit_post_link($dtwpb_product_tag_custom_page_id) ).'"> '.esc_html__('Edit', 'dt_woocommerce_page_builder').'</a>';
								}
							?>
							</p>
							</td>							
						</tr>
						
					</tbody>
				</table>
				<table class="form-table">
					<tbody>
						<tr valign="top">
							<th scope="row"><label for="dtwpb_cart_page_id"><?php esc_html_e('Cart Page Template', 'dt_woocommerce_page_builder') ?></label></th>
							<td>
							<?php
							$cart_page_id = dtwpb_get_option('dtwpb_cart_page_id', '');
							
							$cart_tpl = get_posts(array('post_type'=> DTWPB_Cart_Tpl::postType(), 'post_status'=> 'publish,private', 'suppress_filters' => false, 'posts_per_page'=>-1));
							echo '<select name="dtwpb_settings[dtwpb_cart_page_id]" id="dtwpb_cart_page_id" class="" data-placeholder="'.__( 'Select a cart template&hellip;','dt_woocommerce_page_builder').'">';
							echo '<option value="">'. __( '-- None (Use theme layout) --','dt_woocommerce_page_builder') . '</option>';
							foreach ($cart_tpl as $tpl) {
								echo '<option value="'. $tpl->ID .'" '. selected( $cart_page_id , $tpl->ID, false ) .'>'. $tpl->post_title. '</option>';
							}
							echo '</select>';
							?>
							<p class="description"><?php esc_html_e('Select Cart page custom template.', 'dt_woocommerce_page_builder');
								echo '<br/>';
								if( !empty($cart_page_id) ){
									echo '<a href="'.esc_url( get_edit_post_link($cart_page_id) ).'"> '.esc_html__('Edit', 'dt_woocommerce_page_builder').'</a>';
								}?>
							</p>
							</td>
						</tr>
						<tr valign="top">
							<th scope="row"><label for="dtwpb_cartempty_page_id"><?php esc_html_e('Cart Empty Page Template', 'dt_woocommerce_page_builder') ?></label></th>
							<td>
							<?php
							$cartempty_page_id = dtwpb_get_option('dtwpb_cartempty_page_id', '');
							
							$cartempty_tpl = get_posts(array('post_type'=> DTWPB_Cart_Tpl::postType(), 'post_status'=> 'publish,private', 'suppress_filters' => false, 'posts_per_page'=>-1));
							echo '<select name="dtwpb_settings[dtwpb_cartempty_page_id]" id="dtwpb_cartempty_page_id" class="" data-placeholder="'.__( 'Select a template&hellip;','dt_woocommerce_page_builder').'">';
							echo '<option value="">'. __( '-- None (Use theme layout) --','dt_woocommerce_page_builder') . '</option>';
							foreach ($cartempty_tpl as $tpl) {
								echo '<option value="'. $tpl->ID .'" '. selected( $cartempty_page_id , $tpl->ID, false ) .'>'. $tpl->post_title. '</option>';
							}
							echo '</select>';
							?>
							<p class="description"><?php esc_html_e('Select Cart Empty page custom template.', 'dt_woocommerce_page_builder');
								echo '<br/>';
								if( !empty($cartempty_page_id) ){
									echo '<a href="'.esc_url( get_edit_post_link($cartempty_page_id) ).'"> '.esc_html__('Edit', 'dt_woocommerce_page_builder').'</a>';
								}?>
							</p>
							</td>
						</tr>
						<tr valign="top">
							<th scope="row"><label for="dtwpb_checkout_page_id"><?php esc_html_e('Checkout Page Template', 'dt_woocommerce_page_builder') ?></label></th>
							<td>
							<?php
							$checkout_page_id = dtwpb_get_option('dtwpb_checkout_page_id', '');
							
							$checkout_tpl = get_posts(array('post_type'=> DTWPB_Checkout_Tpl::postType(), 'post_status'=> 'publish,private', 'suppress_filters' => false, 'posts_per_page'=>-1));
							echo '<select name="dtwpb_settings[dtwpb_checkout_page_id]" id="dtwpb_checkout_page_id" class="" data-placeholder="'.__( 'Select a checkout template&hellip;','dt_woocommerce_page_builder').'">';
							echo '<option value="">'. __( '-- None (Use theme layout) --','dt_woocommerce_page_builder') . '</option>';
							foreach ($checkout_tpl as $tpl) {
								echo '<option value="'. $tpl->ID .'" '. selected( $checkout_page_id , $tpl->ID, false ) .'>'. $tpl->post_title. '</option>';
							}
							echo '</select>';
							?>
							<p class="description">
							<?php esc_html_e('Select Checkout page custom template.');
								echo '<br/>';
								if( !empty($checkout_page_id) ){
								echo '<a href="'.esc_url( get_edit_post_link($checkout_page_id) ).'"> '.esc_html__('Edit', 'dt_woocommerce_page_builder').'</a>';
								}?>
							</p>
							</td>		
						</tr>
						
					</tbody>
				</table>
				<table class="form-table">
					<tbody>
						<tr valign="top">
							<th scope="row"><label for="dtwpb_thankyou_page_id"><?php esc_html_e('Thank You Template', 'dt_woocommerce_page_builder') ?></label></th>
							<td>
							<?php
							$dtwpb_thankyou_page_id = dtwpb_get_option('dtwpb_thankyou_page_id', '');
							
							$thankyou_tpl = get_posts(array('post_type'=> DTWPB_Thankyou_Tpl::postType(), 'post_status'=> 'publish,private', 'suppress_filters' => false, 'posts_per_page'=>-1));
							echo '<select name="dtwpb_settings[dtwpb_thankyou_page_id]" id="dtwpb_thankyou_page_id" class="" data-placeholder="'.__( 'Select a template&hellip;','dt_woocommerce_page_builder').'">';
							echo '<option value="">'. __( '-- None (Use theme layout) --','dt_woocommerce_page_builder') . '</option>';
							foreach ($thankyou_tpl as $tpl) {
								echo '<option value="'. $tpl->ID .'" '. selected( $dtwpb_thankyou_page_id , $tpl->ID, false ) .'>'. $tpl->post_title. '</option>';
							}
							echo '</select>';
							?>
							<p class="description"><?php esc_html_e('Select Thank you custom template.', 'dt_woocommerce_page_builder');
								echo '<br/>';
								if( !empty($dtwpb_thankyou_page_id) ){
									echo '<a href="'.esc_url( get_edit_post_link($dtwpb_thankyou_page_id) ).'"> '.esc_html__('Edit', 'dt_woocommerce_page_builder').'</a>';
								}?>
							</p>
							</td>
						</tr>
					</tbody>
				</table>
				<table class="form-table">
					<tbody>
						<tr valign="top">
							<th scope="row"><label for="dtwpb_woocommerce_myaccount_before_login_page_id"><?php esc_html_e('My Account Before Login Page Template', 'dt_woocommerce_page_builder') ?></label></th>
							<td>
							<?php
							$myaccount_login_page_id = dtwpb_get_option('dtwpb_woocommerce_myaccount_before_login_page_id', '');
							
							$myaccount_tpl = get_posts(array('post_type'=> DTWPB_MyAccount_Tpl::postType(), 'post_status'=> 'publish,private', 'suppress_filters' => false, 'posts_per_page'=>-1));
							echo '<select name="dtwpb_settings[dtwpb_woocommerce_myaccount_before_login_page_id]" id="dtwpb_woocommerce_myaccount_before_login_page_id" class="" data-placeholder="'.__( 'Select My Account template&hellip;','dt_woocommerce_page_builder').'">';
							echo '<option value="">'. __( '-- None (Use theme layout) --','dt_woocommerce_page_builder') . '</option>';
							foreach ($myaccount_tpl as $tpl) {
								echo '<option value="'. $tpl->ID .'" '. selected( $myaccount_login_page_id, $tpl->ID, false ) .'>'. $tpl->post_title. '</option>';
							}
							echo '</select>';
							
							?>
							<p class="description">
								<?php 
								esc_html_e('Custom page before user login. Go to build a custom MyAccount Before login page, use the elements in the "Woo MyAccount Before Login". You can also add the steps/description how to create an account for this custom page.', 'dt_woocommerce_page_builder');
								echo '<br/>';
								if( !empty($myaccount_login_page_id) ){
									echo '<a href="'.esc_url( get_edit_post_link($myaccount_login_page_id) ).'"> '.esc_html__('Edit', 'dt_woocommerce_page_builder').'</a>';
								}?>
								</p>
							</td>					
						</tr>
						
						<tr valign="top">
							<th scope="row"><label for="dtwpb_myaccount_page_id"><?php esc_html_e('My Account Page Template', 'dt_woocommerce_page_builder') ?></label></th>
							<td>
							<?php
							$myaccount_page_id = dtwpb_get_option('dtwpb_myaccount_page_id', '');
	
							if( !empty($myaccount_page_id) && $myaccount_page_id === $myaccount_login_page_id ){
								$myaccount_page_id = 0;
								echo '<div class="update-message notice inline notice-warning notice-alt">'.esc_html__('You can\'t use the Login Template for My Account page.', 'dt_woocommerce_page_builder').'</div>';
							}
							
							$myaccount_tpl = get_posts(array('post_type'=> DTWPB_MyAccount_Tpl::postType(), 'post_status'=> 'publish,private', 'suppress_filters' => false, 'posts_per_page'=>-1));
							echo '<select name="dtwpb_settings[dtwpb_myaccount_page_id]" id="dtwpb_myaccount_page_id" class="" data-placeholder="'.__( 'Select My Account template&hellip;','dt_woocommerce_page_builder').'">';
							echo '<option value="">'. __( '-- None (Use theme layout) --','dt_woocommerce_page_builder') . '</option>';
							foreach ($myaccount_tpl as $tpl) {
								echo '<option value="'. $tpl->ID .'" '. selected( $myaccount_page_id, $tpl->ID, false ) .'>'. $tpl->post_title. '</option>';
							}
							echo '</select>';
							?>
							<p class="description">
								<?php esc_html_e('Select My Account page custom template.', 'dt_woocommerce_page_builder');
								echo '<br/>';
								if( !empty($myaccount_page_id) ){
									echo '<a href="'.esc_url( get_edit_post_link($myaccount_page_id) ).'"> '.esc_html__('Edit', 'dt_woocommerce_page_builder').'</a>';
								}?>
								</p>
							</td>					
						</tr>
						
						<tr valign="top">
							<th scope="row"><label for="dtwpb_set_edit_account_page_id"><?php esc_html_e('Account Details Template', 'dt_woocommerce_page_builder') ?></label></th>
							<td>
							<?php
							$dtwpb_set_edit_account_page_id = dtwpb_get_option('dtwpb_set_edit_account_page_id', '');
							
							$myaccount_tpl = get_posts(array('post_type'=> DTWPB_MyAccount_Tpl::postType(), 'post_status'=> 'publish,private', 'suppress_filters' => false, 'posts_per_page'=>-1));
							echo '<select name="dtwpb_settings[dtwpb_set_edit_account_page_id]" id="dtwpb_set_edit_account_page_id" class="" data-placeholder="'.__( 'Select a template&hellip;','dt_woocommerce_page_builder').'">';
							echo '<option value="">'. __( '-- None (Use theme layout) --','dt_woocommerce_page_builder') . '</option>';
							foreach ($myaccount_tpl as $tpl) {
								echo '<option value="'. $tpl->ID .'" '. selected( $dtwpb_set_edit_account_page_id, $tpl->ID, false ) .'>'. $tpl->post_title. '</option>';
							}
							echo '</select>';
							?>
							<p class="description">
								<?php esc_html_e('Select Account Details Template.', 'dt_woocommerce_page_builder');
								echo '<br/>';
								if( !empty($dtwpb_set_edit_account_page_id) ){
									echo '<a href="'.esc_url( get_edit_post_link($dtwpb_set_edit_account_page_id) ).'"> '.esc_html__('Edit', 'dt_woocommerce_page_builder').'</a>';
								}?>
								</p>
							</td>					
						</tr>
						
					</tbody>
				</table>
			</div>
			<p>
				<button type="submit" id="submit-dtwpb-form" class="button button-primary "><?php esc_html_e('SAVE CHANGES','woocommerce');?></button>
			</p>
		</form>
		<?php
		}
	
		/**
		 * Change the admin footer text on WooCommerce admin pages.
		 *
		 * @since  2.3
		 * @param  string $footer_text
		 * @return string
		 */
		public function admin_footer_text( $footer_text ) {
			if ( ! function_exists( 'dtwpb_get_screen_ids' ) ) {
				return $footer_text;
			}
			$current_screen = get_current_screen();
			$dtwpb_pages       = dtwpb_get_screen_ids();
		
			// Set only WC pages.
			$dtwpb_pages = array_diff( $dtwpb_pages, array( 'profile', 'user-edit' ) );
		
			// Check to make sure we're on a WooCommerce admin page.
			if ( isset( $current_screen->id ) && in_array( $current_screen->id, $dtwpb_pages ) ) {
				// Change the footer text
					$footer_text = sprintf(
						/* translators: 1: WooCommerce 2:: five stars */
						__( 'If you like %1$s please leave us a %2$s rating. A huge thanks in advance!', 'dt_woocommerce_page_builder' ),
						sprintf( '<strong>%s</strong>', esc_html__( 'WooCommerce Page Builder', 'dt_woocommerce_page_builder' ) ),
						'<a href="https://codecanyon.net/item/woocommerce-page-builder/15534462" target="_blank" class="wc-rating-link" data-rated="' . esc_attr__( 'Thanks :)', 'dt_woocommerce_page_builder' ) . '">&#9733;&#9733;&#9733;&#9733;&#9733;</a>'
					);
			}
		
			return $footer_text;
		}
		
	public function add_meta_boxes(){
		global $post;
		
		add_meta_box('dtwpb-single-product-meta-box', __( 'DTWPB Single Product Page', 'dt_woocommerce_page_builder'), array($this, 'add_product_meta_box'), 'product', 'side');
		
	}
	
	public function add_product_meta_box(){
		
		$product_id = get_the_ID();
		$selected_product_template_id	= get_post_meta($product_id, 'dtwpb_single_product_page', true);

		$dtwpb_product_tpl_type_page = dtwpb_get_option('dtwpb_product_tpl_type_page', 'dtwpb_product_tpl');
		$post_type = ($dtwpb_product_tpl_type_page == 'page') ? 'page' : 'dtwpb_product_tpl';
		
		$selected = absint($selected_product_template_id);
		$posts = get_posts(array('post_type'=> $post_type, 'post_status'=> 'publish,private', 'suppress_filters' => false, 'posts_per_page'=>-1));
		echo '<select name="dtwpb_single_product_page" id="dtwpb_single_product_page" class="" data-placeholder="'.__( 'Select a template&hellip;','dt_woocommerce_page_builder').'">';
		echo '<option value="">'. __( 'Default','dt_woocommerce_page_builder') . '</option>';
		foreach ($posts as $post) {
			echo '<option value="'. $post->ID .'"'. ($selected == $post->ID ? ' selected="selected"' : '') .'>'. $post->post_title. '</option>';
		}
		echo '</select>';
		?>
		<p class="description"><?php echo sprintf( __( 'Select a product template. Default is use in %sProduct Template Default%s setting.', 'dt_woocommerce_page_builder' ), '<a href="' . esc_url( admin_url( 'admin.php?page=woocommerce-page-builder-settings' ) ) . '" target="_blank">', '</a>' ); ?></p>

		<input type="hidden" name="dtwpb-single-product-page-nonce" id="dtwpb-single-product-page-nonce" value="<?php echo esc_attr( wp_create_nonce( 'dtwpb-single-product-page-set' ) ); ?>">
	<?php
	}
	
	
	public function save_product_meta_data( $post_id, $post  ){
		$post_id = absint( $post_id );

		// $post_id and $post are required
		if ( empty( $post_id ) || empty( $post ) ) {
			return;
		}

		// Dont' save meta boxes for revisions or autosaves.
		if ( ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) || is_int( wp_is_post_revision( $post ) ) || is_int( wp_is_post_autosave( $post ) ) ) {
			return;
		}

		// Check user's permissions.
		if ( ! current_user_can( 'edit_post', $post_id ) ) {
			return $post_id;
		}

		// Check nonce.
		if ( ! isset( $_POST['dtwpb-single-product-page-nonce'] ) || ! wp_verify_nonce( sanitize_text_field( wp_unslash( $_POST['dtwpb-single-product-page-nonce'] ) ), 'dtwpb-single-product-page-set' ) ) {
			return $post_id;
		}
		
		if(!empty($_POST['dtwpb_single_product_page'])){
			update_post_meta( $post_id, 'dtwpb_single_product_page', absint($_POST['dtwpb_single_product_page']) );
		}else{
			delete_post_meta( $post_id, 'dtwpb_single_product_page');
		}
	}
	
	public function add_category_fields(){
		?>
		<div class="form-field">
			<label for="dtwpb_cat_product_page"><?php _e( 'DTWPB Single Product Page', 'dt_woocommerce_page_builder' ); ?></label>
			<?php
			$product_type = dtwpb_get_option('dtwpb_product_tpl_type_page', 'dtwpb_product_tpl');
			
			$posts = get_posts(array('post_type'=> $product_type, 'post_status'=> 'publish,private', 'suppress_filters' => false, 'posts_per_page'=>-1));
			echo '<select name="dtwpb_cat_product_page" id="dtwpb_cat_product_page" class="enhanced chosen_select_nostd" data-placeholder="'.__( 'Select a product template&hellip;','dt_woocommerce_page_builder').'">';
			echo '<option value="">'. __( 'None','dt_woocommerce_page_builder') . '</option>';
			foreach ($posts as $post) {
				echo '<option value="'. $post->ID .'">'. $post->post_title. '</option>';
			}
			echo '</select>';
			?>
			<p class="description"><?php echo sprintf( __( 'Select a product template or %sCreate new%s template. This template will be applied for all products of the category.', 'dt_woocommerce_page_builder' ), '<a href="' . esc_url( admin_url( 'post-new.php?post_type='.$product_type ) ) . '" target="_blank">', '</a>' ); ?></p>
		</div>
		
		<div class="form-field">
			<label for="dtwpb_product_cat_custom_page"><?php esc_html_e( 'DTWPB Product Archive Page', 'dt_woocommerce_page_builder' ); ?></label>
			<?php 
			$cat_type = dtwpb_get_option('dtwpb_cat_tpl_type_page', 'dtwpb_cat_tpl');
				
			$posts = get_posts(array('post_type'=> $cat_type, 'post_status'=> 'publish,private', 'suppress_filters' => false, 'posts_per_page'=>-1));
			echo '<select name="dtwpb_product_cat_custom_page" id="dtwpb_product_cat_custom_page" class="enhanced chosen_select_nostd" data-placeholder="'.esc_attr__( 'Select a category template&hellip;','dt_woocommerce_page_builder').'">';
			echo '<option value="">'. esc_html__( 'None','dt_woocommerce_page_builder') . '</option>';
			foreach ($posts as $post) {
				echo '<option value="'. $post->ID .'">'. $post->post_title. '</option>';
			}
			echo '</select>';
			?>
			<br/><br/><input type="checkbox" name="dtwpb_product_cat_custom_page_child" value="1">
				<span><?php _e( 'Apply Product Archive template for the Child Categories', 'dt_woocommerce_page_builder' ); ?></span>
			<p class="description"><?php echo sprintf( __( 'Select Product Archive Template or %sCreate new%s template.', 'dt_woocommerce_page_builder' ), '<a href="' . esc_url( admin_url( 'post-new.php?post_type='.$cat_type ) ) . '" target="_blank">', '</a>' ); ?></p>
		</div>
		<div class="form-field">
			<br/>
		</div>
		<?php
	}
	
	public function edit_category_fields( $term, $taxonomy ) {
		$dtwpb_cat_product_page = get_term_meta( $term->term_id, 'dtwpb_cat_product_page', true );
		$dtwpb_product_archive_custom_page = get_term_meta( $term->term_id, 'dtwpb_product_cat_custom_page', true );
		$dtwpb_product_archive_custom_page_child = get_term_meta( $term->term_id, 'dtwpb_product_cat_custom_page_child', true );

		?>
		<tr class="form-field">
			<th scope="row" valign="top"><label><?php _e( 'DTWPB Single Product Page', 'dt_woocommerce_page_builder' ); ?></label></th>
			<td>
				<?php
				$product_type = dtwpb_get_option('dtwpb_product_tpl_type_page', 'dtwpb_product_tpl');
				
				$selected = absint($dtwpb_cat_product_page);
				$posts = get_posts(array('post_type'=> $product_type, 'post_status'=> 'publish,private', 'suppress_filters' => false, 'posts_per_page'=>-1));
				echo '<select name="dtwpb_cat_product_page" id="dtwpb_cat_product_page" class="enhanced chosen_select_nostd" data-placeholder="'.__( 'Select a product template&hellip;','dt_woocommerce_page_builder').'">';
				echo '<option value="">'. __( 'None','dt_woocommerce_page_builder') . '</option>';
				foreach ($posts as $post) {
					echo '<option value="'. $post->ID .'"'. ($selected == $post->ID ? ' selected="selected"' : '') .'>'. $post->post_title. '</option>';
				}
				echo '</select>';
				?>
				<p class="description"><?php echo sprintf( __( 'Select a product template or %sCreate new%s template. This template will be applied for all products of the category.', 'dt_woocommerce_page_builder' ), '<a href="' . esc_url( admin_url( 'post-new.php?post_type='.$product_type ) ) . '" target="_blank">', '</a>' ); ?></p>
				
			</td>
		</tr>
		
		<tr class="form-field">
			<th scope="row" valign="top"><label><?php _e( 'DTWPB Product Archive Page', 'dt_woocommerce_page_builder' ); ?></label></th>
			<td>
				<?php 
				$cat_type = dtwpb_get_option('dtwpb_cat_tpl_type_page', 'dtwpb_cat_tpl');
			
				$selected = absint($dtwpb_product_archive_custom_page);
				$posts = get_posts(array('post_type'=> $cat_type, 'post_status'=> 'publish,private', 'suppress_filters' => false, 'posts_per_page'=>-1));
				echo '<select name="dtwpb_product_cat_custom_page" id="dtwpb_product_cat_custom_page" class="enhanced chosen_select_nostd" data-placeholder="'.__( 'Select a category template&hellip;','dt_woocommerce_page_builder').'">';
				echo '<option value="">'. __( 'None','dt_woocommerce_page_builder') . '</option>';
				foreach ($posts as $post) {
					echo '<option value="'. $post->ID .'"'. ($selected == $post->ID ? ' selected="selected"' : '') .'>'. $post->post_title. '</option>';
				}
				echo '</select>';
				?>
				<p class="description"><?php echo sprintf( __( 'Select a Product Archive Template or %sCreate new%s template.', 'dt_woocommerce_page_builder' ), '<a href="' . esc_url( admin_url( 'post-new.php?post_type='.$cat_type ) ) . '" target="_blank">', '</a>' ); ?></p>
			</td>
			
			
		</tr>
		<tr class="form-field">
			<th scope="row" valign="top"></th>
			<td>
				<input type="checkbox" name="dtwpb_product_cat_custom_page_child" value="1" <?php checked($dtwpb_product_archive_custom_page_child, 1, true); ?>>
				<span><?php _e( 'Apply Product Archive Template for the Child Categories', 'dt_woocommerce_page_builder' ); ?></span>
			</td>
		</tr>
		<?php
	}
	
	public function save_category_fields( $term_id, $tt_id, $taxonomy ) {
	
		if(!empty($_POST['dtwpb_cat_product_page'])){
			update_term_meta( $term_id, 'dtwpb_cat_product_page', absint( $_POST['dtwpb_cat_product_page'] ) );
		}else{
			delete_term_meta($term_id,  'dtwpb_cat_product_page');
		}

		if ( isset( $_POST[sanitize_key('dtwpb_product_cat_thumbnail_id')] ) ) {
			update_term_meta( $term_id, 'dtwpb_product_cat_thumbnail_id', absint( $_POST['dtwpb_product_cat_thumbnail_id'] ) );
		}
		
		if(!empty($_POST['dtwpb_product_cat_custom_page'])){
			update_term_meta( $term_id, 'dtwpb_product_cat_custom_page', absint( $_POST['dtwpb_product_cat_custom_page'] ) );
		}else{
			delete_term_meta($term_id,  'dtwpb_product_cat_custom_page');
		}

		if(!empty($_POST['dtwpb_product_cat_custom_page_child'])){
			update_term_meta( $term_id, 'dtwpb_product_cat_custom_page_child', absint( $_POST['dtwpb_product_cat_custom_page_child'] ) );
		}else{
			delete_term_meta($term_id,  'dtwpb_product_cat_custom_page_child');
		}

		if(!empty($_POST['dtwpb_product_tag_custom_page'])){
			update_term_meta( $term_id, 'dtwpb_product_tag_custom_page', absint( $_POST['dtwpb_product_tag_custom_page'] ) );
		}else{
			delete_term_meta($term_id,  'dtwpb_product_tag_custom_page');
		}
	}

	public function add_product_tag_fields(){
		?>
		
		<div class="form-field">
			<label for="dtwpb_product_tag_custom_page"><?php esc_html_e( 'DTWPB Product Archive Page', 'dt_woocommerce_page_builder' ); ?></label>
			<?php 
			$archive_type = dtwpb_get_option('dtwpb_cat_tpl_type_page', 'dtwpb_cat_tpl');
				
			$posts = get_posts(array('post_type'=> $archive_type, 'post_status'=> 'publish,private', 'suppress_filters' => false, 'posts_per_page'=>-1));
			echo '<select name="dtwpb_product_tag_custom_page" id="dtwpb_product_tag_custom_page" class="enhanced chosen_select_nostd" data-placeholder="'.esc_attr__( 'Select a Produc Archive template&hellip;','dt_woocommerce_page_builder').'">';
			echo '<option value="">'. esc_html__( 'None','dt_woocommerce_page_builder') . '</option>';
			foreach ($posts as $post) {
				echo '<option value="'. $post->ID .'">'. $post->post_title. '</option>';
			}
			echo '</select>';
			?>
			<p class="description"><?php echo sprintf( __( 'Select a Produc Archive template for Product Tag page or %sCreate new%s template.', 'dt_woocommerce_page_builder' ), '<a href="' . esc_url( admin_url( 'post-new.php?post_type='.$archive_type ) ) . '" target="_blank">', '</a>' ); ?></p>
		</div>
		<div class="form-field">
			<br/>
		</div>
		<?php
	}

	public function edit_product_tag_fields( $term, $taxonomy ) {
		
		$dtwpb_product_tag_custom_page = get_term_meta( $term->term_id, 'dtwpb_product_tag_custom_page', true );

		?>
		
		<tr class="form-field">
			<th scope="row" valign="top"><label><?php _e( 'DTWPB Product Archive Page', 'dt_woocommerce_page_builder' ); ?></label></th>
			<td>
				<?php 
				$archive_type = dtwpb_get_option('dtwpb_cat_tpl_type_page', 'dtwpb_cat_tpl');
				
				$selected = absint($dtwpb_product_tag_custom_page);
				$posts = get_posts(array('post_type'=> $archive_type, 'post_status'=> 'publish,private', 'suppress_filters' => false, 'posts_per_page'=>-1));
				echo '<select name="dtwpb_product_tag_custom_page" id="dtwpb_product_tag_custom_page" class="enhanced chosen_select_nostd" data-placeholder="'.__( 'Select a Produc Archive template&hellip;','dt_woocommerce_page_builder').'">';
				echo '<option value="">'. __( 'None','dt_woocommerce_page_builder') . '</option>';
				foreach ($posts as $post) {
					echo '<option value="'. $post->ID .'"'. ($selected == $post->ID ? ' selected="selected"' : '') .'>'. $post->post_title. '</option>';
				}
				echo '</select>';
				?>
				<p class="description"><?php echo sprintf( __( 'Select a Produc Archive template for Product Tag page or %sCreate new%s template.', 'dt_woocommerce_page_builder' ), '<a href="' . esc_url( admin_url( 'post-new.php?post_type='.$archive_type ) ) . '" target="_blank">', '</a>' ); ?></p>
			</td>
			
		</tr>
		<?php
	}
	
	
	// End Class
}

new WooCommercePageBuilder_Admin();
